@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2007-2022 Statnet Commons
+ *  Copyright 2007-2024 Statnet Commons
  */
 #include <R.h>
 #include <Rinternals.h>
@@ -21,6 +21,7 @@ extern SEXP log_sum_exp_wrapper(SEXP, SEXP);
 extern SEXP logspace_wmean_wrapper(SEXP, SEXP);
 extern SEXP logspace_wmean2_wrapper(SEXP, SEXP);
 extern SEXP logspace_wmeans_wrapper(SEXP, SEXP);
+extern SEXP logspace_wxmean_wrapper(SEXP, SEXP, SEXP);
 extern SEXP sweep2m(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
@@ -28,6 +29,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"logspace_wmean_wrapper",  (DL_FUNC) &logspace_wmean_wrapper,  2},
     {"logspace_wmean2_wrapper", (DL_FUNC) &logspace_wmean2_wrapper, 2},
     {"logspace_wmeans_wrapper", (DL_FUNC) &logspace_wmeans_wrapper, 2},
+    {"logspace_wxmean_wrapper", (DL_FUNC) &logspace_wxmean_wrapper, 3},
     {"sweep2m",                 (DL_FUNC) &sweep2m,                 2},
     {NULL, NULL, 0}
 };
